@@ -12,8 +12,8 @@ Additional SCons Options
 --show-config: <existence>
     List configuration read from files.
 
---config-user: string
-    Override the user-config file to read for configuration.
+--config-files: string
+    Override the user-config files to read for configuration.
 
 
 Attributes
@@ -21,7 +21,7 @@ Attributes
 decider_str_lookup : dict
     Dictionary mapping string to objects that SCons' Decider function can handle.
     Can be used to easily specify our new Decider function 'content-timestamp-newer' which only runs a task
-    if a depenency is different than last time SCons ran and a dependency is newer than all the targets 
+    if a depenency is different than last time SCons ran and a dependency is newer than all the targets
     (this means that if you run scripts outside of SCons, we won't rebuild them):
     Decider(pystatacons.decider_str_lookup['content-timestamp-newer'])
 
@@ -32,6 +32,7 @@ special_sig_fns : dict
 
 """
 
-__version__ = "2.1.1"
+__version__ = "2.1.2"
 __all__ = ['init_env', 'decider_str_lookup', 'special_sig_fns', 'stata_run_params_factory']
-from .sconstruct_aux import decider_str_lookup, dependency_newer_then_content_changed, changed_timestamp_then_dependency_newer_then_content_content, special_sig_fns, init_env, stata_run_params_factory
+from .sconstruct_aux import decider_str_lookup, dependency_newer_then_content_changed, \
+    changed_timestamp_then_dependency_newer_then_content_content, special_sig_fns, init_env, stata_run_params_factory
