@@ -5,6 +5,7 @@ from pkg_resources import packaging
 import sys
 from pathlib import Path  # scons' Glob is not recursive
 import platform
+from typing import Union
 
 import SCons
 from SCons.Defaults import DefaultEnvironment
@@ -13,6 +14,7 @@ import SCons.Script
 from SCons.Script import AddOption, GetOption, SetOption
 from SCons.Builder import Builder
 import SCons.Node.FS
+from SCons.Environment import Environment
 
 
 has_pywin32 = False
@@ -43,19 +45,20 @@ def query_config(env, header, key, default=None):
     return default
 
 
-def configuration(config_user_ini='config_user.ini', config_project_ini='config_project.ini'):
+def configuration(config_files=['config_project.ini', 'config_local.ini']):
     import shutil
     import configparser
     # Copies templates if no such file exists
-    if not os.path.isfile(config_user_ini) and os.path.isfile('utils/config_user_template.ini'):
-        shutil.copy('utils/config_user_template.ini', config_user_ini)
+    if len(config_files) > 1 and config_files[0] == 'config_local.ini' and \
+       not os.path.isfile('config_local.ini') and os.path.isfile('utils/config_local_template.ini'):
+        shutil.copy('utils/config_local_template.ini', 'config_local.ini')
 
     CONFIG = configparser.ConfigParser()
     # Load the easy defaults initially
     CONFIG['SCons'] = {'success_batch_log_dir': '', 'use_custom_datasignature': 'Strict', 'stata_chdir': ''}
 
-    # Loads config ini files (user ones can over-ride project ones)
-    config_files = [f for f in [config_project_ini, config_user_ini] if os.path.isfile(f)]
+    # Loads config ini files (local ones can over-ride project ones)
+    config_files = [f for f in config_files if os.path.isfile(f)]
     CONFIG.read(config_files)
 
     # Remove quotes form paths if people are confused
@@ -68,7 +71,7 @@ def configuration(config_user_ini='config_user.ini', config_project_ini='config_
     strip_quotes_config('Project', 'cache_dir', CONFIG)
 
     # Check values
-    if CONFIG['SCons']['success_batch_log_dir']!="" and not os.path.isdir(CONFIG['SCons']['success_batch_log_dir']):
+    if CONFIG['SCons']['success_batch_log_dir'] != "" and not os.path.isdir(CONFIG['SCons']['success_batch_log_dir']):
         print("Warning: couldn't find directory 'success_batch_log_dir'")
 
     if not CONFIG['SCons']['stata_chdir'] in ['', '0', '1'] and not os.path.isdir(CONFIG['SCons']['stata_chdir']):
@@ -86,11 +89,11 @@ def configuration(config_user_ini='config_user.ini', config_project_ini='config_
 
 
 AddOption(
-    '--config-user',
-    dest='config_user',
+    '--config-files',
+    dest='config_files',
     action='store',
     type="string",
-    help='Specify config_user file path.',
+    help='Specify config file paths.',
 )
 
 
@@ -260,7 +263,8 @@ def try_hidden_desktop(cmd_line, cwd=None, disp_str=""):
     proc_ret = win32process.CreateProcess(None, cmd_line, None, None, False, 0, None, cwd, s)
     # hProcess, _, dwProcessId, _
     if disp_str != "":
-        print_during_build(disp_str + ". Starting in hidden desktop (pid=" + str(proc_ret[2]) + ")." + "\n")
+        print_during_build(disp_str + "." + "\n" + "  Starting in hidden desktop (pid=" + str(proc_ret[2]) + ")."
+                           + "\n")
     win32event.WaitForSingleObject(proc_ret[0], win32event.INFINITE)
     ret_code = win32process.GetExitCodeProcess(proc_ret[0])
     return ret_code
@@ -392,8 +396,9 @@ builder_counter = 1
 task_dependencies = []
 
 
-def stata_run_params_factory(self, target, source=None, do_file=None, params="", file_cmd="do", full_cmd=None,
-                             depends=None):
+def stata_run_params_factory(self: Environment, target: Union[list, str], source: Union[list, str] = None,
+                             do_file: str = None, params: str = "", file_cmd: str = "do", full_cmd: str = None,
+                             depends: list = None) -> SCons.Node.NodeList:
     """Factory function to create Builder instances for Stata tasks.
 
     Typically called as env.StataBuild() and omitting the first (self) argument.
@@ -414,29 +419,24 @@ def stata_run_params_factory(self, target, source=None, do_file=None, params="",
 
     Parameters
     ----------
-    self : Environment
+    self :
         Environment
-    target : list or str
+    target :
         Targets of the task
-    source : list or str
+    source :
         Sources of the task. If mulitple, then the first should be the Stata script file.
-    do_file : str
+    do_file :
         Alternative way of specifying the do file.
-    params : str
+    params :
         Parameters to the script execution
-    file_cmd : str
+    file_cmd :
         Override 'do' command for the script.
-    file_cmd : str
+    file_cmd :
         Alternative to (file_cmd, script file, params) for specifying the full command
-    depends : list
+    depends :
         Additional dependencies of the task. Equivalent to using Depends().
-
-    Returns
-    -------
-    Builder instance
-        Builder instance for this task
-
     """
+
     # partial approach doesn't work because the signature includes the address of original function
     env = self  # self is env
 
@@ -658,14 +658,15 @@ def monkey_patch_scons(m_str=""):
     SCons.Node.FS.File.get_csig = get_csig_new
 
 
-def init_env(env=None, patch_scons_sig_fns=True, skip_scons_vs_check=False):
+def init_env(env: Environment = None, patch_scons_sig_fns: bool = True,
+             skip_scons_vs_check: bool = False) -> Environment:
     """Sets up an environment for Stata.
 
     Reads configuration data and saves to env['CONFIG']. By default it will check for and read
-    two ini files ('config_project.ini' then 'config_user.ini'), though the latter
-    can be overridden using the '--config-user=....' option.
-    If the config_user.ini does not exist, but 'utils/config_user_template.ini' does, the latter is copied
-    to the former location.
+    two ini files ('config_project.ini' then 'config_local.ini'), though
+    can be overridden using the '--config-files=....' option.
+    If the config_local.ini is the first one, does not exist and 'utils/config_local_template.ini' does,
+    the latter is copied to the former location.
 
     Displays the config if the '--show-config' option was specified.
     Runs a Stata Tool to find Stata automatically.
@@ -676,21 +677,15 @@ def init_env(env=None, patch_scons_sig_fns=True, skip_scons_vs_check=False):
 
     Parameters
     ----------
-    env : Environment
+    env :
         Environment to configure for Stata support. If not provided will instantiate a DefaultEnvironment with the
         `os.environ` and no tools (many Stata users don't have defaults ones that SCons would complain about not
         finding).
-    patch_scons_sig_fns : bool
+    patch_scons_sig_fns :
         Whether to patch the SCons file signature functions to support special signature functions by file extensions.
         Default support is provided for .dta files.
-    skip_scons_vs_check: bool
+    skip_scons_vs_check:
         If false, will not output a warning when using a version of SCons that has not been tested.
-
-    Returns
-    -------
-    Environment
-        Environment setup with Stata support.
-
     """
     if not skip_scons_vs_check and packaging.version.parse(SCons.__version__) < packaging.version.parse("4.2.0"):
         print("WARNING: You are running SCons version" + SCons.__version__
@@ -701,8 +696,8 @@ def init_env(env=None, patch_scons_sig_fns=True, skip_scons_vs_check=False):
     global int_env
     int_env = env
 
-    if GetOption("config_user") is not None:
-        config = configuration(config_user_ini=GetOption("config_user"))
+    if GetOption("config_files") is not None:
+        config = configuration(config_files=GetOption("config_files").split(':'))
     else:
         config = configuration()
 
